#!/bin/ksh



function checkversion 
{
    if [[ -f ${TOPHPU}/bin/db2hpu ]] ; then
        VERSION=`${TOPHPU}/bin/db2hpu -v 2>&1`
        VERSION2=${VERSION##* }
        if [[ "${VERSION2}" > "${HOTVERSION}" ]] ; then
            echo "Version ${VERSION2} is too high to apply the HotFix ${HOTFIX}"
            return 8
        else
            if [[ "${VERSION2}" = "${HOTVERSION}" ]] ; then
                echo "Version ${VERSION2} is already installed"
                return 8
            else
                if [[ "${VERSION2}" < "${HOTBASE}" ]] ; then 
                   echo "Version ${VERSION2} is too low to apply the HotFix ${HOTFIX}"
                   return 8
                else
                   echo "Found Version ${VERSION2}, HotFix ${HOTFIX} can be applied."
                   return 0
                fi
            fi
        fi
    else
        echo "Error: Could not verify the version"
        return 8
    fi
}    

# Fix  parameters
HOTFIX="HF215H"
HOTVERSION="02.01.005H"
HOTBASE="02.01.005"
HOTOS="AIX"


# Get the OS
OS=`uname -s`

echo "------ High Performance Unload for DB2"
echo "-"
echo "------ HotFix ${HOTFIX} for ${HOTOS}"
echo "-"
if [[ "${OS}" != "${HOTOS}" ]] ; then
    echo "Error: This Fix is for ${HOTOS}, and this is ${OS}"
    exit 8
fi
echo "- The Hotfix will be applied to the current version,"
echo "- located at: ${TOPHPU}"
echo "-"
echo "- The following actions will be taken"
DIRBASE=`dirname $0`
while read FILENAME ; do
    case ${FILENAME} in
    "daemonstop" )
        echo "Stopping the daemon"
        ;;
    "daemonstart" )
        echo "Starting the daemon"
        ;;
    "plugin" )
        echo "Updating the plugin"
        ;;
    "cfg" )
        echo "Updating the config file"
        ;;
    * )
        echo "Updating ${TOPHPU}/${FILENAME}"
        ;;
    esac
done < ${DIRBASE}/filelist.txt
echo "-"
echo "- All replaced files will be renamed by adding the extention _${HOTFIX}"
echo "- "
echo "- YOU NEED TO BE ROOT to run this HotFix"
echo "-"
echo "- Type 'install' to install the HotFix or 'quit' to abort"
ANSWER=" "
read ANSWER
case ${ANSWER} in
"install" )
    echo "- Installing HotFix...."
    if  [[ ! -d ${TOPHPU} ]]  ; then
        echo "Fatal Error: ${TOPHPU} does not exist or is not a directory"
        exit 8
    fi
    checkversion
    if [[ $? -ne 0 ]] ; then
        exit 8
    fi
    if [[ -e ${TOPHPU}/ptf ]] ; then
        if [[ -d ${TOPHPU}/ptf ]] ; then
            if [[ -e ${TOPHPU}/ptf/${HOTFIX} ]] ; then
                if [[ -d ${TOPHPU}/ptf/${HOTFIX} ]] ; then
                    echo ""
                else
                    echo "Error: ${TOPHPU}/ptf/${HOTFIX} exists and is not a directory"
                    exit 8
                fi
            else
                mkdir ${TOPHPU}/ptf/${HOTFIX}
            fi
        else
           echo "Error: ${TOPHPU}/ptf/${HOTFIX} exists and is not a directory"
           exit 8
        fi
    else
        mkdir ${TOPHPU}/ptf
        mkdir ${TOPHPU}/ptf/${HOTFIX}
    fi
    cp ${DIRBASE}/filelist.txt ${TOPHPU}/ptf/${HOTFIX}/filelist_${HOTFIX}
    cp -p ${DIRBASE}/uninstall.sh ${TOPHPU}/ptf/${HOTFIX}/uninstall.sh
    

    while read FILENAME ; do
        case ${FILENAME} in
        "daemonstop" )
            echo "Stopping the daemon"
            ${TOPHPU}/bin/db2hpud stop
            ;;
        "daemonstart" )
            echo "Starting the daemon"
            ${TOPHPU}/bin/db2hpud start
            ;;
        "plugin" )
            echo "Updating the plugin"
            ;;
        "cfg" )
            echo "Updating the config file"
            ;;
        * )
            if [[ -f ${TOPHPU}/${FILENAME} ]] ; then
                echo "Backing up ${TOPHPU}/${FILENAME}"     
                mv ${TOPHPU}/${FILENAME} ${TOPHPU}/${FILENAME}_${HOTFIX}
            else
                echo "Warning File ${TOPHPU}/${FILENAME} not Present"
            fi
            cp -p ${DIRBASE}/${FILENAME} ${TOPHPU}/${FILENAME}
            ;;
        esac
    done < ${DIRBASE}/filelist.txt
    echo ""
    echo "Installation completed..."
    exit 0
    ;;   

"quit"|* )
    echo "- Installation cancelled.... No update done."
    exit 1
    ;;
esac
   

