#!/bin/ksh

set -u

DIRBASE=`dirname $0`
if [[ ${DIRBASE} != . ]] ; then
    echo "Error: HotFix uninstall must be executed from its own directory "
    exit 8
fi

HOTFIX=`basename ${PWD}`
if [[ ! -f ${DIRBASE}/filelist_${HOTFIX} ]] ; then
    echo "Error: rollback filelist is not available"
    exit 8
fi

echo "------ High Performance Unload for DB2"
echo "-"
echo "- The Hotfix ${HOTFIX} will be uninstalled"
echo "- from: ${TOPHPU}"
echo "-"
echo "- The following actions will be taken"
while read FILENAME ; do
    case ${FILENAME} in
    "daemonstop" )
        echo "Stopping the daemon"
        ;;
    "daemonstart" )
        echo "Starting the daemon"
        ;;
    "plugin" )
        echo "Restoring the plugin"
        ;;
    "cfg" )
        echo "Restoring the config file"
        ;;
    * )
        if [[ -f ${TOPHPU}/${FILENAME}_${HOTFIX} ]] ; then
            echo "Restoring ${TOPHPU}/${FILENAME}"
        else
            echo "Error ${TOPHPU}/${FILENAME}_${HOTFIX} is not available, cannot restore ${FILENAME}"
            exit 8
        fi
        ;;
    esac
done < ${DIRBASE}/filelist_${HOTFIX}


echo "- "
echo "- YOU NEED TO BE ROOT to run this HotFix"
echo "-"
echo "- Type 'uninstall' to uninstall the HotFix or 'quit' to abort"
ANSWER=" "
read ANSWER
case ${ANSWER} in
"uninstall" )
    echo "- Uninstalling HotFix...."
    while read FILENAME ; do
        case ${FILENAME} in
        "daemonstop" )
            echo "Stopping the daemon"
            ${TOPHPU}/bin/db2hpud stop
            ;;
        "daemonstart" )
            echo "Starting the daemon"
            ${TOPHPU}/bin/db2hpud start
            ;;
        "plugin" )
            echo "Restoring the plugin"
            ;;
        "cfg" )
            echo "Restoring the config file"
            ;;
        * )
            echo "Restoring ${TOPHPU}/${FILENAME}"     
            rm ${TOPHPU}/${FILENAME}
            mv ${TOPHPU}/${FILENAME}_${HOTFIX} ${TOPHPU}/${FILENAME}
            ;;
        esac
    done < ${DIRBASE}/filelist_${HOTFIX}
    echo ""
    echo "Uninstallation completed..."
    exit 0
    ;;

"quit"|* )
    echo "- Uninstallation cancelled.... No update done."
    exit 1
    ;;
esac


